@@ -24,7 +24,7 @@ class DeferredAttr(DeferredItem):
         self.name = name
         self.attr = attr
 
-    def get_value(self):
+    def resolve(self):
         return getattr(self.obj, self.attr)
 
     def __str__(self):
@@ -36,11 +36,11 @@ class DeferredContent(DeferredItem):
         super(DeferredContent, self).__init__()
         self.out = out
 
-    def get_value(self):
+    def resolve(self):
         return self.out.read()
 
     def __str__(self):
-        return "{0} content".format(self.out)
+        return "{0} has".format(self.out)
 
 
 class File(Printable):
@@ -86,7 +86,7 @@ class File(Printable):
             raise ValueError('%s was closed' % self.fd.name)
 
     def find(self, substring):
-        raise TypeError("use 'content' attribute to refer file contest")
+        raise TypeError("use 'content' attribute to refer file content")
 
 #        with file(self.path) as fd:
 #            return fd.read().find(substring)
@@ -102,7 +102,7 @@ class File(Printable):
     def content(self):
         return DeferredContent(self)
 
-#    def get_value(self):
+#    def resolve(self):
 #        return self.read()
 
     def __unicode__(self):
